# Feature: [FEAT-XXX] [Title]

**Epic:** EPIC-XXX
**Status:** Draft | In Progress | Done
**Created:** YYYY-MM-DD
**Last Updated:** YYYY-MM-DD
**Last Modified By:** [git user email]

---

## Description

[Feature description - mid-level capability]

---

## User Value

[Why this feature matters to users]

---

## Stories

| Story ID | Title | Status | Priority |
|----------|-------|--------|----------|
| STORY-001 | [Story Title] | Draft | P1 |

---

## Acceptance Criteria (Feature Level)

- [ ] **AC1**: [High-level acceptance criterion]
- [ ] **AC2**: [High-level acceptance criterion]

---

## Dependencies

### Story Dependencies

| Dependency | Story ID | Status | Type |
|------------|----------|--------|------|
| Depends On | STORY-001 | Done | Must complete first |

### External Dependencies

| System | Owner | Contract | Notes |
|--------|-------|----------|-------|
| [External System] | [Owner] | [Contract path] | [Version/notes] |

---

## History

| Date | Change | By |
|------|--------|-----|
| YYYY-MM-DD | Created | [Name] |
